# Define libsuffix.
%global libsuffix yui
%global libname lib%{libsuffix}

# Do we build with Mono?
%ifarch %{mono_arches}
%global with_mono 1
%endif # arch %%{mono_arches}

# Do we build with Python3?
%if 0%{?fedora} >= 13 || 0%{?rhel} >= 8
%global with_py3 1
%endif #0%{?fedora} >= 13 || 0%{?rhel} >= 8

# Setup _pkgdocdir if not defined already.
%{!?_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# CMake-builds go out-of-tree.
%global _cmake_build_subdir build-%{?_arch}%{?dist}

Name:		%{libname}-bindings
Version:	1.1.0
Release:	3%{?dist}
Summary:	Language bindings for %{libname}

License:	LGPLv2 or LGPLv3
URL:		https://github.com/%{libname}/%{name}
Source0:	%{url}/archive/%{name}/master/%{version}.tar.gz#/%{name}-%{version}.tar.gz

#Upstream-patch for older CMake.
Patch0:		%{url}/commit/80844d20b3c00965e698ddcef7d36e43f2edbe62.patch#/libyui-1.1.0-cmake_new_policy_only_if_available.patch

BuildRequires:	cmake			>= 2.8
BuildRequires:	%{libname}-devel
BuildRequires:	swig

%description
This package provides Mono / CSharp, Perl, Python and Ruby language
bindings to access functions of %{libname}.
An User Interface engine that provides abstraction from graphical user
interfaces (Qt, Gtk) and text based user interfaces (ncurses).


%if 0%{?with_mono}
%package -n mono-%{libsuffix}
Summary:	Mono / CSharp bindings for %{libname}
BuildRequires:	mono-devel

%description -n mono-%{libsuffix}
This package provides Mono / CSharp language bindings to access
functions of %{libname}.
An User Interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user
interfaces (ncurses).
%endif # 0%%{?with_mono}


%package -n perl-%{libsuffix}
Summary:	Perl bindings for %{libname}

BuildRequires:	perl-devel
Requires:	perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description -n perl-%{libsuffix}
This package provides Perl language bindings to access
functions of %{libname}.
An User Interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user
interfaces (ncurses).


%package -n python-%{libsuffix}
Summary:	Python bindings for %{libname}
BuildRequires:	python2-devel

%description -n python-%{libsuffix}
This package provides Python language bindings to access
functions of %{libname}.
An User Interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user
interfaces (ncurses).


%if 0%{?with_py3}
%package -n python3-%{libsuffix}
Summary:	Python3 bindings for %{libname}
BuildRequires:	python3-devel

%description -n python3-%{libsuffix}
This package provides Python3 language bindings to access
functions of %{libname}.
An User Interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user
interfaces (ncurses).
%endif #0%{?with_py3}


%package -n ruby-%{libsuffix}
Summary:	Ruby bindings for %{libname}

BuildRequires:	ruby-devel

%if 0%{?fedora} >= 19 || 0%{?rhel} >= 7
Requires:	ruby(release)
%else #0%{?fedora} >= 19 || 0%{?rhel} >= 7
%if (0%{?fedora} && 0%{?fedora} <= 16) || (0%{?rhel} >= 4 && 0%{?rhel} <= 6)
Requires:	ruby(abi)		== 1.8
%else #(0%{?fedora} && 0%{?fedora} <= 16) || (0%{?rhel} >= 4 && 0%{?rhel} <= 6)
Requires:	ruby(abi)		== 1.9.1
%endif #(0%{?fedora} && 0%{?fedora} <= 16) || (0%{?rhel} >= 4 && 0%{?rhel} <= 6)
%endif #0%{?fedora} >= 19 || 0%{?rhel} >= 7

%description -n ruby-%{libsuffix}
This package provides Ruby language bindings to access
functions of %{libname}.
An User Interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user
interfaces (ncurses).


%prep
%setup -qn %{name}-%{name}-master-%{version}
%patch0 -p1
%{__cp} -a package/%{libname}-bindings.changes ChangeLog


%build
%{__mkdir} -p %{_cmake_build_subdir}
pushd %{_cmake_build_subdir}
%cmake							\
	-DLIB=%{_libdir}				\
	-DMONO_LIBRARIES=%{_libdir}			\
	-DPython_ADDITIONAL_VERSIONS=%{python2_version}	\
	-DPYTHON_EXECUTABLE=%{__python2}		\
	-DPYTHON_SITEDIR=%{python2_sitearch}		\
	-DCMAKE_BUILD_TYPE=RELEASE			\
	-DBUILD_RUBY_GEM=no				\
	-DWITH_MONO=%{?with_mono:ON}%{!?with_mono:OFF}	\
	-DWITH_PERL=ON					\
	-DWITH_PYTHON=ON				\
	-DWITH_RUBY=ON					\
	..

%{__make} %{?_smp_mflags}
popd

%if 0%{?with_py3}
%{__mkdir} -p py3-%{_cmake_build_subdir}
pushd py3-%{_cmake_build_subdir}
%cmake							\
	-DLIB=%{_libdir}				\
	-DPython_ADDITIONAL_VERSIONS=%{python3_version}	\
	-DPYTHON_EXECUTABLE=%{__python3}		\
	-DPYTHON_SITEDIR=%{python3_sitearch}		\
	-DCMAKE_BUILD_TYPE=RELEASE			\
	-DBUILD_RUBY_GEM=no				\
	-DWITH_MONO=OFF					\
	-DWITH_PERL=OFF					\
	-DWITH_PYTHON=ON				\
	-DWITH_RUBY=OFF					\
	..

%{__make} %{?_smp_mflags}
popd
%endif #0%{?with_py3}


%install
pushd %{_cmake_build_subdir}
%make_install

# Install documentation.
%{__mkdir} -p	%{buildroot}%{?_pkgdocdir}/mono		\
		%{buildroot}%{?_pkgdocdir}/perl		\
		%{buildroot}%{?_pkgdocdir}/python	\
		%{buildroot}%{?_pkgdocdir}/ruby
%{__cp} -a	../ChangeLog ../COPYING* ../README	\
		%{buildroot}%{?_pkgdocdir}
%if 0%{?with_mono}
%{__cp} -a	swig/mono/*.cs				\
		%{buildroot}%{?_pkgdocdir}/mono
%endif # 0%%{?with_mono}
%{__cp} -a	../swig/perl/examples/*			\
		%{buildroot}%{?_pkgdocdir}/perl
%{__cp} -a	../swig/python/examples/*		\
		%{buildroot}%{?_pkgdocdir}/python
%{__cp} -a	../swig/ruby/examples/*			\
		%{buildroot}%{?_pkgdocdir}/ruby
popd

%if 0%{?with_py3}
pushd py3-%{_cmake_build_subdir}
%make_install
popd
%endif #0%{?with_py3}


%if 0%{?with_mono}
%files -n mono-%{libsuffix}
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/ChangeLog
%doc %{?_pkgdocdir}/COPYING*
%doc %{?_pkgdocdir}/mono
%doc %{?_pkgdocdir}/README
%{_libdir}/%{libsuffix}/%{libsuffix}.dll
%{_libdir}/%{libsuffix}/%{libsuffix}.so
%endif

%files -n perl-%{libsuffix}
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/ChangeLog
%doc %{?_pkgdocdir}/COPYING*
%doc %{?_pkgdocdir}/perl
%doc %{?_pkgdocdir}/README
%{perl_vendorarch}/%{libsuffix}.so
%{perl_vendorlib}/%{libsuffix}.pm

%files -n python-%{libsuffix}
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/ChangeLog
%doc %{?_pkgdocdir}/COPYING*
%doc %{?_pkgdocdir}/python
%doc %{?_pkgdocdir}/README
%{python2_sitearch}/*%{libsuffix}.*

%if 0%{?with_py3}
%files -n python3-%{libsuffix}
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/ChangeLog
%doc %{?_pkgdocdir}/COPYING*
%doc %{?_pkgdocdir}/python
%doc %{?_pkgdocdir}/README
%{python3_sitearch}/__pycache__/*
%{python3_sitearch}/*%{libsuffix}.*
%endif #0%{?with_py3}

%files -n ruby-%{libsuffix}
%doc %dir %{?_pkgdocdir}
%doc %{?_pkgdocdir}/ChangeLog
%doc %{?_pkgdocdir}/COPYING*
%doc %{?_pkgdocdir}/README
%doc %{?_pkgdocdir}/ruby
%{ruby_vendorarchdir}/_%{libsuffix}.*


%changelog
* Thu Jan 22 2015 Björn Esser <bjoern.esser@gmail.com> - 1.1.0-3
- add Patch0: use upstream-patch for older CMake instead of sed-cludge

* Thu Jan 22 2015 Dan Horák <dan[at]danny.cz> - 1.1.0-2
- fix build without Mono

* Tue Jan 20 2015 Björn Esser <bjoern.esser@gmail.com> - 1.1.0-1
- new upstream release
- rebuilt for libyui-3.1.5
- keep doc-files in unfied %%{_pkgdocdir}
- small improvements to spec-file
- drop Patch0, now in upstream sources

* Sun Jan 18 2015 Mamoru TASAKA <mtasaka@fedoraproject.org> - 0.5.0-6
- Rebuild for https://fedoraproject.org/wiki/Changes/Ruby_2.2
- Remove deprecated Config: usage

* Wed Aug 27 2014 Jitka Plesnikova <jplesnik@redhat.com> - 1.0.4-4
- Perl 5.20 rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Björn Esser <bjoern.esser@gmail.com> - 1.0.4-1
- new upstream version
- build a Python3 version
- minor improvents on spec

* Thu Apr 24 2014 Vít Ondruch <vondruch@redhat.com> - 1.0.2-11
- Rebuilt for https://fedoraproject.org/wiki/Changes/Ruby_2.1

* Tue Mar 18 2014 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-10
- rebuilt for libyui-3.0.13

* Wed Oct 02 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-9
- added "Versioned MODULE_COMPAT_ Requires"

* Wed Oct 02 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-8
- adaptions for new Python-guidelines
- use %%{ruby_vendorarchdir} instead of hardcoded path

* Fri Aug 30 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-7
- libyui 3.0.10 rebuilt

* Sat Aug 03 2013 Petr Pisar <ppisar@redhat.com> - 1.0.2-6
- Perl 5.18 rebuild

* Sat Jul 27 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-5
- include examples in own subdir
- removed hardening flags

* Sat Jul 27 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-4
- fix build, removed trailing backslash

* Sat Jul 27 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-3
- libyui-3.0.9 rebuilt on all branches
- removed Group-tag

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.0.2-2
- Perl 5.18 rebuild on F20 / rawhide

* Thu Jun 20 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.2-1
- new upstream-version
- copyright changed GPLv2 -> LGPLv2 or LGPLv3 matching libyui* now.
- removed `/usr/bin/env` from hashbang of examples
- adapted Source0 obsoleting %%commit

* Sat May 18 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.1-2
- improved readability: tag ordering

* Wed May 15 2013 Björn Esser <bjoern.esser@gmail.com> - 1.0.1-1
- Initial RPM release.
